@@ -1,12 +1,8 @@
 //! A command-line executable for generating the chain's genesis config.
 #![allow(clippy::integer_arithmetic)]
 
-#[macro_use]
-extern crate solana_budget_program;
 #[macro_use]
 extern crate solana_exchange_program;
-#[macro_use]
-extern crate solana_vest_program;
 
 use clap::{crate_description, crate_name, value_t, value_t_or_exit, App, Arg, ArgMatches};
 use solana_clap_utils::{
@@ -19,7 +15,7 @@ use solana_ledger::{
 };
 use solana_runtime::hardened_unpack::MAX_GENESIS_ARCHIVE_UNPACKED_SIZE;
 use solana_sdk::{
-    account::{Account, AccountSharedData},
+    account::{Account, AccountSharedData, ReadableAccount, WritableAccount},
     clock,
     epoch_schedule::EpochSchedule,
     fee_calculator::FeeRateGovernor,
@@ -93,8 +89,8 @@ pub fn load_genesis_accounts(file: &str, genesis_config: &mut GenesisConfig) ->
                 })?,
             );
         }
-        account.executable = account_details.executable;
-        lamports += account.lamports;
+        account.set_executable(account_details.executable);
+        lamports += account.lamports();
         genesis_config.add_account(pubkey, account);
     }
 
@@ -463,7 +459,7 @@ fn main() -> Result<(), Box<dyn error::Error>> {
             ClusterType::Development => {
                 let hashes_per_tick =
                     compute_hashes_per_tick(poh_config.target_tick_duration, 1_000_000);
-                poh_config.hashes_per_tick = Some(hashes_per_tick);
+                poh_config.hashes_per_tick = Some(hashes_per_tick / 2); // use 50% of peak ability
             }
             ClusterType::Devnet | ClusterType::Testnet | ClusterType::MainnetBeta => {
                 poh_config.hashes_per_tick = Some(clock::DEFAULT_HASHES_PER_TICK);
@@ -494,11 +490,7 @@ fn main() -> Result<(), Box<dyn error::Error>> {
     );
 
     let native_instruction_processors = if cluster_type == ClusterType::Development {
-        vec![
-            solana_vest_program!(),
-            solana_budget_program!(),
-            solana_exchange_program!(),
-        ]
+        vec![solana_exchange_program!()]
     } else {
         vec![]
     };
